==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_d3_d9_depth_buffer.js <==
var class_ogre_1_1_d3_d9_depth_buffer =
[
    [ "PoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga9854c57374adef41216bae68544a5b7e", [
      [ "POOL_NO_DEPTH", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea569228ed0fdd8d428a5117026b6d010e", null ],
      [ "POOL_MANUAL_USAGE", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea2d5409ddce167e1db415f09ee2160440", null ],
      [ "POOL_DEFAULT", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea00a687046bfe7a9ebd7f34256d3fbcca", null ]
    ] ],
    [ "D3D9DepthBuffer", "class_ogre_1_1_d3_d9_depth_buffer.html#a2bfd06803e6627d29b6eef9fd6bc6319", null ],
    [ "~D3D9DepthBuffer", "class_ogre_1_1_d3_d9_depth_buffer.html#ad0bf97863bd3b2d70e3b46dea48ca8f7", null ],
    [ "isCompatible", "class_ogre_1_1_d3_d9_depth_buffer.html#a9ef76a9564375f4a6b795467000f4d52", null ],
    [ "getDeviceCreator", "class_ogre_1_1_d3_d9_depth_buffer.html#a2c7495ae026d07ef5dd36741f1464941", null ],
    [ "getDepthBufferSurface", "class_ogre_1_1_d3_d9_depth_buffer.html#a52634647b72575019d3ef0396a92d624", null ],
    [ "_setPoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga7af5c611687492846891914dcac303d2", null ],
    [ "getPoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga82b30e2ad5de1ac4678fda52ccbaf28f", null ],
    [ "getBitDepth", "class_ogre_1_1_d3_d9_depth_buffer.html#ga0da54b20b25ac5313fc8c142e8b35168", null ],
    [ "getWidth", "class_ogre_1_1_d3_d9_depth_buffer.html#gae5095fe367bf95d08dee2da03810beb2", null ],
    [ "getHeight", "class_ogre_1_1_d3_d9_depth_buffer.html#gaf95e6998e74db40257cb2ca5cab4bdf4", null ],
    [ "getFsaa", "class_ogre_1_1_d3_d9_depth_buffer.html#gafb31d279263557b92843f6715ba6e8c2", null ],
    [ "getFsaaHint", "class_ogre_1_1_d3_d9_depth_buffer.html#ga2d44455830254b7da1058ad542f9a439", null ],
    [ "isManual", "class_ogre_1_1_d3_d9_depth_buffer.html#ga4a3de78684016598642ad2d00e5caa86", null ],
    [ "_notifyRenderTargetAttached", "class_ogre_1_1_d3_d9_depth_buffer.html#ga26c4ce1003ddab1ed7e3befecb0888a1", null ],
    [ "_notifyRenderTargetDetached", "class_ogre_1_1_d3_d9_depth_buffer.html#ga227b541ef2ae3de53334c10397a08f99", null ]
];

==> ogre-docs-1.12.1-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_d3_d9_depth_buffer.js <==
var class_ogre_1_1_d3_d9_depth_buffer =
[
    [ "PoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga9854c57374adef41216bae68544a5b7e", [
      [ "POOL_NO_DEPTH", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea569228ed0fdd8d428a5117026b6d010e", null ],
      [ "POOL_MANUAL_USAGE", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea2d5409ddce167e1db415f09ee2160440", null ],
      [ "POOL_DEFAULT", "class_ogre_1_1_d3_d9_depth_buffer.html#gga9854c57374adef41216bae68544a5b7ea00a687046bfe7a9ebd7f34256d3fbcca", null ]
    ] ],
    [ "D3D9DepthBuffer", "class_ogre_1_1_d3_d9_depth_buffer.html#a2bfd06803e6627d29b6eef9fd6bc6319", null ],
    [ "~D3D9DepthBuffer", "class_ogre_1_1_d3_d9_depth_buffer.html#ad0bf97863bd3b2d70e3b46dea48ca8f7", null ],
    [ "isCompatible", "class_ogre_1_1_d3_d9_depth_buffer.html#a9ef76a9564375f4a6b795467000f4d52", null ],
    [ "getDeviceCreator", "class_ogre_1_1_d3_d9_depth_buffer.html#a2c7495ae026d07ef5dd36741f1464941", null ],
    [ "getDepthBufferSurface", "class_ogre_1_1_d3_d9_depth_buffer.html#a52634647b72575019d3ef0396a92d624", null ],
    [ "_setPoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga7af5c611687492846891914dcac303d2", null ],
    [ "getPoolId", "class_ogre_1_1_d3_d9_depth_buffer.html#ga82b30e2ad5de1ac4678fda52ccbaf28f", null ],
    [ "getBitDepth", "class_ogre_1_1_d3_d9_depth_buffer.html#ga0da54b20b25ac5313fc8c142e8b35168", null ],
    [ "getWidth", "class_ogre_1_1_d3_d9_depth_buffer.html#gae5095fe367bf95d08dee2da03810beb2", null ],
    [ "getHeight", "class_ogre_1_1_d3_d9_depth_buffer.html#gaf95e6998e74db40257cb2ca5cab4bdf4", null ],
    [ "getFSAA", "class_ogre_1_1_d3_d9_depth_buffer.html#ga37ddc9b5fc1fd8c5cf50e1b865d2b2fb", null ],
    [ "getFSAAHint", "class_ogre_1_1_d3_d9_depth_buffer.html#ga9662342362034428346e0676fb9d1ac7", null ],
    [ "getFsaa", "class_ogre_1_1_d3_d9_depth_buffer.html#ga242e53843f55de3983e6f070e88c19ae", null ],
    [ "getFsaaHint", "class_ogre_1_1_d3_d9_depth_buffer.html#ga1b4eca5bc2774b80081a2f5aba90c58c", null ],
    [ "isManual", "class_ogre_1_1_d3_d9_depth_buffer.html#ga4a3de78684016598642ad2d00e5caa86", null ],
    [ "_notifyRenderTargetAttached", "class_ogre_1_1_d3_d9_depth_buffer.html#ga26c4ce1003ddab1ed7e3befecb0888a1", null ],
    [ "_notifyRenderTargetDetached", "class_ogre_1_1_d3_d9_depth_buffer.html#ga227b541ef2ae3de53334c10397a08f99", null ]
];
